==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebTabComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescriptionMetadata } from "./WebTabDescriptionMetadata";
import { WebTabComponentEventArgsDescription } from "./WebTabComponentEventArgsDescription";
/**
 * @hidden
 */
export let WebTabComponentEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabComponentEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabComponentEventArgsDescriptionMetadata.a == null) {
                WebTabComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabComponentEventArgsDescriptionMetadata.c(WebTabComponentEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebTabComponentEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebTabComponentEventArgsDescriptionMetadata.a);
            WebTabDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TabComponentEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebTab");
        }
        static d(a) {
            WebTabComponentEventArgsDescriptionMetadata.b(a);
            a.ad("WebTabComponentEventArgs", () => new WebTabComponentEventArgsDescription());
            a.ac("WebTabComponentEventArgs", WebTabComponentEventArgsDescriptionMetadata.a);
        }
    }
    WebTabComponentEventArgsDescriptionMetadata.$t = markType(WebTabComponentEventArgsDescriptionMetadata, 'WebTabComponentEventArgsDescriptionMetadata');
    WebTabComponentEventArgsDescriptionMetadata.a = null;
    return WebTabComponentEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebTabComponentEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebTabDescriptionMetadata } from "./WebTabDescriptionMetadata";
import { WebTabComponentEventArgsDescription } from "./WebTabComponentEventArgsDescription";
/**
 * @hidden
 */
export let WebTabComponentEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebTabComponentEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebTabComponentEventArgsDescriptionMetadata.a == null) {
                WebTabComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebTabComponentEventArgsDescriptionMetadata.c(WebTabComponentEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebTabComponentEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebTabComponentEventArgsDescriptionMetadata.a);
            WebTabDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:TabComponentEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "ExportedType:WebTab");
        }
        static d(a) {
            WebTabComponentEventArgsDescriptionMetadata.b(a);
            a.ae("WebTabComponentEventArgs", () => new WebTabComponentEventArgsDescription());
            a.ad("WebTabComponentEventArgs", WebTabComponentEventArgsDescriptionMetadata.a);
        }
    }
    WebTabComponentEventArgsDescriptionMetadata.$t = markType(WebTabComponentEventArgsDescriptionMetadata, 'WebTabComponentEventArgsDescriptionMetadata');
    WebTabComponentEventArgsDescriptionMetadata.a = null;
    return WebTabComponentEventArgsDescriptionMetadata;
})();
